authors_refine This function takes the author list output after the
output has been synthesized for incorrect author matches. It contains a
similarity score cutoff like read_authors. This however is to further
constrain the list. New values ARE NOT created, instead it filters by the
sim_score column in the output file.
Examples
## First gather the authors data.frame from authors_clean
data(BITR)
BITR_authors <- authors_clean(BITR)
#>
#> Splitting author records
#>
|
| | 0%
|
|======= | 10%
|
| | 0%
|
|============== | 20%
|
| | 0%
|
|===================== | 30%
|
| | 0%
|
|============================ | 40%
|
| | 0%
|
|=================================== | 50%
|
| | 0%
|
|========================================== | 60%
|
| | 0%
|
|================================================= | 70%
|
| | 0%
|
|======================================================== | 80%
|
| | 0%
|
|=============================================================== | 90%
|
| | 0%
|
|======================================================================| 100%
#>
#> Splitting addresses.
#>
#> standardizing country names...
#>
#> extracting the names of institutions...
#>
#> extracting cities...
#>
#> extracting states/provinces...
#>
#> extracting country...
#>
#> processing postal codes...
#>
#> review, correction, and clean-up...
#>
#> Please be patient - this might take a bit.
#>
#> (still working on it...)
#>
#> (getting closer...)
#>
#> (not much longer...)
#>
#> (almost done...)
#>
#> (so close...the end is in sight!)
#>
#> (this is it - the last step!)
#>
#> Matching authors
#>
|
| | 0%
|
|== | 2%
|
| | 0%
|
|=== | 4%
|
| | 0%
|
|===== | 7%
|
| | 0%
|
|====== | 9%
|
| | 0%
|
|======== | 11%
|
| | 0%
|
|========= | 13%
|
| | 0%
|
|=========== | 15%
|
| | 0%
|
|============ | 17%
|
| | 0%
|
|============== | 20%
|
| | 0%
|
|=============== | 22%
|
| | 0%
|
|================= | 24%
|
| | 0%
|
|================== | 26%
|
| | 0%
|
|==================== | 28%
|
| | 0%
|
|===================== | 30%
|
| | 0%
|
|======================= | 33%
|
| | 0%
|
|======================== | 35%
|
| | 0%
|
|========================== | 37%
|
| | 0%
|
|=========================== | 39%
|
| | 0%
|
|============================= | 41%
|
| | 0%
|
|============================== | 43%
|
| | 0%
|
|================================ | 46%
|
| | 0%
|
|================================= | 48%
|
| | 0%
|
|=================================== | 50%
|
| | 0%
|
|===================================== | 52%
|
| | 0%
|
|====================================== | 54%
|
| | 0%
|
|======================================== | 57%
|
| | 0%
|
|========================================= | 59%
|
| | 0%
|
|=========================================== | 61%
|
| | 0%
|
|============================================ | 63%
|
| | 0%
|
|============================================== | 65%
|
| | 0%
|
|=============================================== | 67%
|
| | 0%
|
|================================================= | 70%
|
| | 0%
|
|================================================== | 72%
|
| | 0%
|
|==================================================== | 74%
|
| | 0%
|
|===================================================== | 76%
|
| | 0%
|
|======================================================= | 78%
|
| | 0%
|
|======================================================== | 80%
|
| | 0%
|
|========================================================== | 83%
|
| | 0%
|
|=========================================================== | 85%
|
| | 0%
|
|============================================================= | 87%
|
| | 0%
|
|============================================================== | 89%
|
| | 0%
|
|================================================================ | 91%
|
| | 0%
|
|================================================================= | 93%
|
| | 0%
|
|=================================================================== | 96%
|
| | 0%
|
|==================================================================== | 98%
|
| | 0%
|
|======================================================================| 100%
#>
#> Pruning groupings...
BITR_review_df <- BITR_authors$review
BITR_prelim_df <- BITR_authors$prelim
## If accepting the preliminary disambiguation
## from authors_clean() without review:
refine_df <- authors_refine(BITR_review_df, BITR_prelim_df,
sim_score = 0.90, confidence = 5)
## Note that 'sim_score' and 'confidence' are optional arguments and are
## only required if changing the default values.
refine_df <- authors_refine(BITR_review_df, BITR_prelim_df)
## If changes were made to groupID or authorID in the "_review.csv" file:
## then incorporate those changes in a text editor, save the corrections as
## a new file name, load in to R and run `authors_refine()` with the
## new corrections as the review arguement.